==> 0.0.8.tar.gz: lib/yundian_alive.dart <==
import 'yundian_alive_method_channel.dart';
import 'yundian_alive_platform_interface.dart';

class YundianAlive {
  static Future<String?> getPlatformVersion() {
    return YundianAlivePlatform.instance.getPlatformVersion();
  }

  static Future<String?> aliveEncryptAes(Map map) {
    return YundianAlivePlatform.instance.aliveEncryptAes(map);
  }

  static Future<String?> aliveInit(bool isDebug, String appKey, String mchInfo, String riskInfo) {
    return YundianAlivePlatform.instance.aliveInit(isDebug, appKey, mchInfo, riskInfo);
  }

  static Future<String?> aliveStartDetect(String authToken, double distance, bool hasResultPage) {
    return YundianAlivePlatform.instance.aliveStartDetect(authToken, distance, hasResultPage);
  }

  static onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    YundianAlivePlatform.instance.onAliveResultListener(onEvent, onError);
  }

  static Future<String?> aliveRelease() {
    return YundianAlivePlatform.instance.aliveRelease();
  }

  static Future<String?> setLayoutAliveDetectedId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedId(layoutIdName);
  }

  static Future<String?> setLayoutAliveDetectedFailId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedFailId(layoutIdName);
  }

  static Future<String?> setLayoutAliveDetectedPreId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedPreId(layoutIdName);
  }

  static Future<String?> setLayoutAliveDetectedSuccessId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedSuccessId(layoutIdName);
  }

  static Future<String?> setTimeout(int timeout) {
    return YundianAlivePlatform.instance.setTimeout(timeout);
  }

  static Future<String?> aliveActionSize(int actionSize) {
    return YundianAlivePlatform.instance.aliveActionSize(actionSize);
  }

  static Future<String?> aliveSecurityLevel(int securityLevel) {
    return YundianAlivePlatform.instance.aliveSecurityLevel(securityLevel);
  }

  static Future<String?> aliveActionSecond(int actionSecond) {
    return YundianAlivePlatform.instance.aliveActionSecond(actionSecond);
  }
}

==> 0.1.3.tar.gz: lib/yundian_alive.dart <==
import 'yundian_alive_method_channel.dart';
import 'yundian_alive_platform_interface.dart';

class YundianAlive {
  static Future<String?> getPlatformVersion() {
    return YundianAlivePlatform.instance.getPlatformVersion();
  }

  static Future<String?> aliveEncryptAes(Map map) {
    return YundianAlivePlatform.instance.aliveEncryptAes(map);
  }

  static Future<String?> aliveInit(bool isDebug, String appKey, String mchInfo, String riskInfo) {
    return YundianAlivePlatform.instance.aliveInit(isDebug, appKey, mchInfo, riskInfo);
  }

  static Future<String?> aliveStartDetect(String authToken, double distance, bool hasResultPage) {
    return YundianAlivePlatform.instance.aliveStartDetect(authToken, distance, hasResultPage);
  }

  static onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    YundianAlivePlatform.instance.onAliveResultListener(onEvent, onError);
  }

  static Future<String?> aliveRelease() {
    return YundianAlivePlatform.instance.aliveRelease();
  }

  static Future<String?> setLayoutAliveDetectedId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedId(layoutIdName);
  }

  static Future<String?> setLayoutAliveDetectedFailId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedFailId(layoutIdName);
  }

  static Future<String?> setLayoutAliveDetectedPreId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedPreId(layoutIdName);
  }

  static Future<String?> setLayoutAliveDetectedSuccessId(String layoutIdName) {
    return YundianAlivePlatform.instance.setLayoutAliveDetectedSuccessId(layoutIdName);
  }

  static Future<String?> setTimeout(int timeout) {
    return YundianAlivePlatform.instance.setTimeout(timeout);
  }

  static Future<String?> setActionSize(int actionSize) {
    return YundianAlivePlatform.instance.setActionSize(actionSize);
  }

  static Future<String?> setSecurityLevel(int securityLevel) {
    return YundianAlivePlatform.instance.setSecurityLevel(securityLevel);
  }

  static Future<String?> setActionSecond(int actionSecond) {
    return YundianAlivePlatform.instance.setActionSecond(actionSecond);
  }

  static Future<String?> setActionTps(String blinkEyes, String turnHeadNod, String openMouth, String shakeHead) {
    return YundianAlivePlatform.instance.setActionTps(blinkEyes, turnHeadNod, openMouth, shakeHead);
  }
}
